==> qtjambi-quick-debuginfo-linux-x64-6.6.3.jar: sources/QtJambiQuick/QSGD3D12Texture_shell.cpp <==
#include <QtCore/QtGlobal>
#if __has_include(<QtQuick/qsgtexture_platform.h>)
#include <QtQuick/qsgtexture_platform.h>
#endif
#include <QtCore/QVariant>
#include <QtCore/qsize.h>
#include <QtQuick/qquickwindow.h>
#include <QtQuick/qsgtexture.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/CoreAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

#if defined(Q_OS_WIN)



#endif // defined(Q_OS_WIN)

// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QNativeInterface::QSGD3D12Texture::nativeResourceState()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_nativeinterface_QSGD3D12Texture_00024Impl_00024ConcreteWrapper_nativeResourceState_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
#if defined(Q_OS_WIN)
        const QNativeInterface::QSGD3D12Texture *__qt_this = QtJambiAPI::interfaceFromNativeId<QNativeInterface::QSGD3D12Texture>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNativeInterface::QSGD3D12Texture::nativeResourceState()const", __qt_this)
        __java_return_value = __qt_this->nativeResourceState();
#else
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // defined(Q_OS_WIN)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNativeInterface::QSGD3D12Texture::nativeTexture()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_nativeinterface_QSGD3D12Texture_00024Impl_00024ConcreteWrapper_nativeTexture_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if defined(Q_OS_WIN)
        const QNativeInterface::QSGD3D12Texture *__qt_this = QtJambiAPI::interfaceFromNativeId<QNativeInterface::QSGD3D12Texture>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNativeInterface::QSGD3D12Texture::nativeTexture()const", __qt_this)
        void* __qt_return_value = __qt_this->nativeTexture();
        __java_return_value = QtJambiAPI::convertNativeToQNativePointer(__jni_env, __qt_return_value, QNativePointer::Type::Pointer, 1, 1);
#else
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // defined(Q_OS_WIN)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNativeInterface::QSGD3D12Texture::fromNative(void*,int,QQuickWindow*,QSize,QQuickWindow::CreateTextureOptions)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_nativeinterface_QSGD3D12Texture_00024Impl_fromNative_1native_1void_1ptr_1int_1QQuickWindow_1ptr_1cref_1QSize_1QQuickWindow_1CreateTextureOptions__Lio_qt_QNativePointer_2IJJI)
(JNIEnv *__jni_env,
 jclass,
 jobject texture0,
 jint resourceState1,
 QtJambiNativeID window2,
 QtJambiNativeID size3,
 jint options4)
{
    QTJAMBI_NATIVE_METHOD_CALL("QNativeInterface::QSGD3D12Texture::fromNative(void*,int,QQuickWindow*,QSize,QQuickWindow::CreateTextureOptions)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if defined(Q_OS_WIN)
        void* __qt_texture0 = reinterpret_cast<void* >(QtJambiAPI::convertQNativePointerToNative(__jni_env, texture0));
        QQuickWindow* __qt_window2 = QtJambiAPI::objectFromNativeId<QQuickWindow>(window2);
        const QSize& __qt_size3 = QtJambiAPI::valueReferenceFromNativeId<QSize>(size3);
        QQuickWindow::CreateTextureOptions __qt_options4 = qtjambi_cast<QQuickWindow::CreateTextureOptions>(__jni_env, options4);
        QSGTexture* __qt_return_value = QNativeInterface::QSGD3D12Texture::fromNative(__qt_texture0, static_cast<int>(resourceState1), __qt_window2, __qt_size3, QQuickWindow::CreateTextureOptions(__qt_options4));
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnershipForTopLevelObject(__jni_env, __qt_return_value);
#else
        Q_UNUSED(texture0)
        Q_UNUSED(resourceState1)
        Q_UNUSED(window2)
        Q_UNUSED(size3)
        Q_UNUSED(options4)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // defined(Q_OS_WIN)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QNativeInterface_QSGD3D12Texture(){
    using namespace RegistryAPI;

#if defined(Q_OS_WIN)

    const std::type_info& typeId = registerInterfaceTypeInfo<QNativeInterface::QSGD3D12Texture>("QNativeInterface::QSGD3D12Texture", "io/qt/quick/nativeinterface/QSGD3D12Texture");
    registerNativeInterface<QNativeInterface::QSGD3D12Texture>("io/qt/quick/nativeinterface/QSGD3D12Texture");
// BEGIN: function table
    registerConstructorInfos(typeId, nullptr, {
    });
// END: function table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QNativeInterface::QSGD3D12Texture* _object = dynamic_cast<QNativeInterface::QSGD3D12Texture*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QNativeInterface::QSGD3D12Texture *object = reinterpret_cast<QNativeInterface::QSGD3D12Texture *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QNativeInterface::QSGD3D12Texture *object = reinterpret_cast<const QNativeInterface::QSGD3D12Texture *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#else //defined(Q_OS_WIN)

    registerNativeInterface("io/qt/quick/nativeinterface/QSGD3D12Texture", {});

#endif //defined(Q_OS_WIN)

}

==> qtjambi-quick-debuginfo-linux-x64-6.7.2.jar: sources/QtJambiQuick/QSGD3D12Texture_shell.cpp <==
#include <QtCore/QtGlobal>
#if __has_include(<QtQuick/qsgtexture_platform.h>)
#include <QtQuick/qsgtexture_platform.h>
#endif
#include <QtCore/QVariant>
#include <QtCore/qsize.h>
#include <QtQuick/qquickwindow.h>
#include <QtQuick/qsgtexture.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/CoreAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

#if defined(Q_OS_WIN)



#endif // defined(Q_OS_WIN)

// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QNativeInterface::QSGD3D12Texture::nativeResourceState()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_nativeinterface_QSGD3D12Texture_00024Impl_00024ConcreteWrapper_nativeResourceState_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
#if defined(Q_OS_WIN)
        const QNativeInterface::QSGD3D12Texture *__qt_this = QtJambiAPI::interfaceFromNativeId<QNativeInterface::QSGD3D12Texture>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNativeInterface::QSGD3D12Texture::nativeResourceState()const", __this_nativeId)
        __java_return_value = __qt_this->nativeResourceState();
#else
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // defined(Q_OS_WIN)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNativeInterface::QSGD3D12Texture::nativeTexture()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_nativeinterface_QSGD3D12Texture_00024Impl_00024ConcreteWrapper_nativeTexture_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if defined(Q_OS_WIN)
        const QNativeInterface::QSGD3D12Texture *__qt_this = QtJambiAPI::interfaceFromNativeId<QNativeInterface::QSGD3D12Texture>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNativeInterface::QSGD3D12Texture::nativeTexture()const", __this_nativeId)
        void* __qt_return_value = __qt_this->nativeTexture();
        __java_return_value = QtJambiAPI::convertNativeToQNativePointer(__jni_env, __qt_return_value, QNativePointer::Type::Pointer, 1, 1);
#else
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // defined(Q_OS_WIN)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNativeInterface::QSGD3D12Texture::fromNative(void*,int,QQuickWindow*,QSize,QQuickWindow::CreateTextureOptions)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_nativeinterface_QSGD3D12Texture_00024Impl_fromNative_1native_1void_1ptr_1int_1QQuickWindow_1ptr_1cref_1QSize_1QQuickWindow_1CreateTextureOptions__Lio_qt_QNativePointer_2IJJI)
(JNIEnv *__jni_env,
 jclass,
 jobject texture0,
 jint resourceState1,
 QtJambiNativeID window2,
 QtJambiNativeID size3,
 jint options4)
{
    QTJAMBI_NATIVE_METHOD_CALL("QNativeInterface::QSGD3D12Texture::fromNative(void*,int,QQuickWindow*,QSize,QQuickWindow::CreateTextureOptions)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if defined(Q_OS_WIN)
        void* __qt_texture0 = reinterpret_cast<void*>(QtJambiAPI::convertQNativePointerToNative(__jni_env, texture0));
        QQuickWindow* __qt_window2 = QtJambiAPI::objectFromNativeId<QQuickWindow>(window2);
        const QSize& __qt_size3 = QtJambiAPI::valueReferenceFromNativeId<QSize>(size3);
        QQuickWindow::CreateTextureOptions __qt_options4 = qtjambi_cast<QQuickWindow::CreateTextureOptions>(__jni_env, options4);
        QSGTexture* __qt_return_value = QNativeInterface::QSGD3D12Texture::fromNative(__qt_texture0, static_cast<int>(resourceState1), __qt_window2, __qt_size3, QQuickWindow::CreateTextureOptions(__qt_options4));
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnershipForTopLevelObject(__jni_env, __qt_return_value);
#else
        Q_UNUSED(texture0)
        Q_UNUSED(resourceState1)
        Q_UNUSED(window2)
        Q_UNUSED(size3)
        Q_UNUSED(options4)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // defined(Q_OS_WIN)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QNativeInterface_QSGD3D12Texture(){
    using namespace RegistryAPI;

#if defined(Q_OS_WIN)

    const std::type_info& typeId = registerInterfaceTypeInfo<QNativeInterface::QSGD3D12Texture>("QNativeInterface::QSGD3D12Texture", "io/qt/quick/nativeinterface/QSGD3D12Texture");
    registerNativeInterface<QNativeInterface::QSGD3D12Texture>("io/qt/quick/nativeinterface/QSGD3D12Texture");
// BEGIN: function table
    registerConstructorInfos(typeId, 0, nullptr, {
    });
// END: function table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QNativeInterface::QSGD3D12Texture* _object = dynamic_cast<QNativeInterface::QSGD3D12Texture*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QNativeInterface::QSGD3D12Texture *object = reinterpret_cast<QNativeInterface::QSGD3D12Texture *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QNativeInterface::QSGD3D12Texture *object = reinterpret_cast<const QNativeInterface::QSGD3D12Texture *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#else //defined(Q_OS_WIN)

    registerNativeInterface("io/qt/quick/nativeinterface/QSGD3D12Texture", {});

#endif //defined(Q_OS_WIN)

}
